Command Line Tool
=================


``intake-esm`` provides a CLI tool for building collection catalogs from the command line:

.. click:: intake_esm.cli:main
   :prog: intake-esm-builder
   :show-nested:
